package io.sixminutes.breakingnews

import android.content.Intent
import android.net.Uri
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.gestures.detectTapGestures
import androidx.compose.foundation.layout.*
import androidx.compose.material3.Text
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.geometry.Offset
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.input.pointer.pointerInput
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp

class ClickTrackerActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            ClickTrackerScreen()
        }
    }
}

@Composable
fun ClickTrackerScreen() {
    var clickCount by remember { mutableStateOf(0) }
    var lastClickPosition by remember { mutableStateOf("No clicks yet") }
    val context = LocalContext.current // 获取当前 Context

    Box(
        modifier = Modifier
            .fillMaxSize()
            .pointerInput(Unit) {
                detectTapGestures { offset ->
                    // 更新点击坐标
                    lastClickPosition = "Last click: (${offset.x.toInt()}, ${offset.y.toInt()})"
                    clickCount++
                    // 如果点击次数达到 10 次，打开系统浏览器
                    if (clickCount >= 10) {
                        val intent = Intent(Intent.ACTION_VIEW, Uri.parse("https://www.google.com"))
                        context.startActivity(intent) // 使用 context 启动 Activity
                    }
                }
            },
        contentAlignment = Alignment.Center
    ) {
        Column(
            horizontalAlignment = Alignment.CenterHorizontally,
            verticalArrangement = Arrangement.Center
        ) {
            Text(
                text = lastClickPosition,
                fontSize = 20.sp,
                color = Color.Black
            )
            Spacer(modifier = Modifier.height(16.dp))
            Text(
                text = "Click count: $clickCount",
                fontSize = 20.sp,
                color = Color.Black
            )
        }
    }
}