package io.sixminutes.breakingnews

import android.content.Intent
import android.os.Build
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.result.contract.ActivityResultContracts
import androidx.compose.foundation.layout.*
import androidx.compose.material3.Button
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.unit.dp
import io.sixminutes.breakingnews.ui.theme.BreakingnewsTheme
import kotlin.system.exitProcess

class MainActivity : ComponentActivity() {
    private val TAG = "breakingNews"

    // 定义 ActivityResultLauncher
    private val interstitialLauncher = registerForActivityResult(
        ActivityResultContracts.StartActivityForResult()
    ) { result ->
        if (result.resultCode == RESULT_OK) {
            val status = result.data?.getStringExtra("AD_STATUS") ?: "Unknown"
            // 更新广告状态
            updateAdStatus(status)
        }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        ActivityManager.addActivity(this)

        setContent {
            // 将 adStatus 提升到 setContent 作用域
            var adStatus by remember { mutableStateOf("Ad Status: Unknown") }

            BreakingnewsTheme {
                Scaffold(modifier = Modifier.fillMaxSize()) { innerPadding ->
                    Box(
                        modifier = Modifier
                            .fillMaxSize()
                            .padding(innerPadding),
                        contentAlignment = Alignment.Center
                    ) {
                        // 将 adStatus 作为参数传递给 MainContent
                        MainContent(
                            adStatus = adStatus,
                            onAdStatusUpdate = { newStatus ->
                                adStatus = newStatus
                            },
                            onShowAd1 = {
                                InterstitialAdManager.showAd(this@MainActivity, "be20b7a9d66e8895", interstitialLauncher)
                                adStatus = "Ad 1 Loading..."
                            },
                            onShowAd2 = {
                                InterstitialAdManager.showAd(this@MainActivity, "be20b7a9d66e8896", interstitialLauncher)
                                adStatus = "Ad 2 Loading..."
                            },
                            onKillApp = {
                                ActivityManager.finishAll()
                                exitProcess(0)
                            }
                        )
                    }
                }
            }
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        ActivityManager.removeActivity(this)
    }

    private fun updateAdStatus(status: String) {
        // 更新 UI 中的广告状态
        runOnUiThread {
            setContent {
                var adStatus by remember { mutableStateOf(status) }

                BreakingnewsTheme {
                    Scaffold(modifier = Modifier.fillMaxSize()) { innerPadding ->
                        Box(
                            modifier = Modifier
                                .fillMaxSize()
                                .padding(innerPadding),
                            contentAlignment = Alignment.Center
                        ) {
                            MainContent(
                                adStatus = adStatus,
                                onAdStatusUpdate = { newStatus ->
                                    adStatus = newStatus
                                },
                                onShowAd1 = {
                                    InterstitialAdManager.showAd(this@MainActivity, "be20b7a9d66e8895", interstitialLauncher)
                                    adStatus = "Ad 1 Loading..."
                                },
                                onShowAd2 = {
                                    InterstitialAdManager.showAd(this@MainActivity, "be20b7a9d66e8896", interstitialLauncher)
                                    adStatus = "Ad 2 Loading..."
                                },
                                onKillApp = {
                                    ActivityManager.finishAll()
                                    exitProcess(0)
                                }
                            )
                        }
                    }
                }
            }
        }
    }
}

@Composable
fun MainContent(
    adStatus: String,
    onAdStatusUpdate: (String) -> Unit,
    onShowAd1: () -> Unit,
    onShowAd2: () -> Unit,
    onKillApp: () -> Unit
) {
    val deviceModel = Build.MODEL
    val context = LocalContext.current

    Column(
        modifier = Modifier.fillMaxSize(),
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Text(text = "Device Model: $deviceModel")
        Spacer(modifier = Modifier.height(16.dp))

        Button(onClick = onShowAd1) {
            Text(text = "Show Inter Ad 1: be20b7a9d66e8895")
        }

        Spacer(modifier = Modifier.height(16.dp))

        Button(onClick = onShowAd2) {
            Text(text = "Show Inter Ad 2: be20b7a9d66e8896")
        }

        Spacer(modifier = Modifier.height(16.dp))

        Button(onClick = onKillApp) {
            Text(text = "Kill")
        }

        Spacer(modifier = Modifier.height(16.dp))

        // 添加 Test 按钮
        Button(onClick = {
            val intent = Intent(context, ClickTrackerActivity::class.java)
            context.startActivity(intent)
        }) {
            Text(text = "Test")
        }

        Spacer(modifier = Modifier.height(16.dp))

        Text(text = adStatus)
    }
}